@@ -15,6 +15,7 @@ from typing import Any, Dict, List, Optional, Tuple, Union
 import docutils.utils
 import rstcheck
 
+from .ansible import get_documentable_plugins, OBJECT_TYPES, OTHER_PLUGIN_TYPES
 from .config import ChangelogConfig, PathsConfig
 from .errors import ChangelogError
 from .logger import LOGGER
@@ -78,7 +79,8 @@ class ChangelogFragment:
         return ChangelogFragment(data, path)
 
     @staticmethod
-    def combine(fragments: List['ChangelogFragment']) -> Dict[str, Union[List[str], str]]:
+    def combine(fragments: List['ChangelogFragment'],
+                ignore_obj_adds: bool = False) -> Dict[str, Union[List[str], str]]:
         """
         Combine fragments into a new fragment.
         """
@@ -86,6 +88,8 @@ class ChangelogFragment:
 
         for fragment in fragments:
             for section, content in fragment.content.items():
+                if section.startswith('add ') and '.' in section and ignore_obj_adds:
+                    continue
                 if isinstance(content, list):
                     lines = result.get(section)
                     if lines is None:
@@ -114,12 +118,91 @@ class ChangelogFragmentLinter:
         """
         self.config = config
 
+    def _lint_add_section(self, errors: List[Tuple[str, int, int, str]],
+                          fragment: ChangelogFragment, section: str,
+                          obj_class: str, obj_type: str, entries: List
+                          # pylint: disable=too-many-arguments
+                          ) -> None:
+        """
+        Lint special 'add (object|plugin).(type)' sections.
+        """
+        is_modules = False
+        if obj_class == 'object':
+            if obj_type not in OBJECT_TYPES:
+                errors.append((fragment.path, 0, 0,
+                               'section "%s"\'s type must be one of %s, not "%s"' % (
+                                   section, ', '.join(OBJECT_TYPES), obj_type)))
+        elif obj_class == 'plugin':
+            if obj_type not in get_documentable_plugins() and obj_type not in OTHER_PLUGIN_TYPES:
+                errors.append((fragment.path, 0, 0,
+                               'section "%s"\'s type must be one of %s, %s, not "%s"' % (
+                                   section,
+                                   ', '.join(get_documentable_plugins()),
+                                   ', '.join(OTHER_PLUGIN_TYPES),
+                                   obj_type)))
+
+            is_modules = obj_type == 'module'
+        else:
+            errors.append((fragment.path, 0, 0,
+                           'section "%s"\'s name must be of format '
+                           '"add (object|plugin).(type)"' % (section, )))
+
+        if not isinstance(entries, list):
+            errors.append((fragment.path, 0, 0,
+                           'section "%s" must be type list '
+                           'not %s' % (section, type(entries).__name__)))
+        else:
+            self._lint_entries(errors, fragment, section, is_modules, entries)
+
+    @staticmethod
+    def _lint_entries(errors: List[Tuple[str, int, int, str]],
+                      fragment: ChangelogFragment, section: str, is_modules: bool,
+                      entries: Any) -> None:
+        """
+        Lint entries in a special 'add (object|plugin).(type)' section.
+        """
+        for index, entry in enumerate(entries):
+            if not isinstance(entry, dict):
+                errors.append((fragment.path, 0, 0,
+                               'section "%s" list items must be type dict '
+                               'not %s' % (section, type(entry).__name__)))
+                continue
+
+            if not isinstance(entry.get('name'), str):
+                errors.append((fragment.path, 0, 0,
+                               'section "%s" entry #%s must have a "name" entry '
+                               'of type string' % (section, index)))
+            if not isinstance(entry.get('description'), str):
+                errors.append((fragment.path, 0, 0,
+                               'section "%s" entry #%s must have a "description" entry '
+                               'of type string' % (section, index)))
+            if not is_modules and entry.get('namespace') is not None:
+                errors.append((fragment.path, 0, 0,
+                               'section "%s" entry #%s must have a "namespace" entry '
+                               'of type string' % (section, index)))
+            if is_modules and not isinstance(entry.get('namespace'), str):
+                errors.append((fragment.path, 0, 0,
+                               'section "%s" entry #%s must not have a non-null "namespace" '
+                               'entry' % (section, index)))
+
+            invalid_keys = sorted([
+                k for k in entry if k not in ('name', 'description', 'namespace')])
+            if invalid_keys:
+                errors.append((fragment.path, 0, 0,
+                               'section "%s" entry #%s has invalid keys %s' % (
+                                   section, index,
+                                   ', '.join(['"%s"' % k for k in invalid_keys]))))
+
     def _lint_section(self, errors: List[Tuple[str, int, int, str]],
                       fragment: ChangelogFragment, section: str,
                       lines: Any) -> None:
         """
         Lint a section of a changelog fragment.
         """
+        if section.startswith('add ') and '.' in section:
+            obj_class, obj_type = section[4:].split('.', 1)
+            self._lint_add_section(errors, fragment, section, obj_class, obj_type, lines)
+            return
         if section == self.config.prelude_name:
             if not isinstance(lines, str):
                 errors.append((fragment.path, 0, 0,
@@ -142,7 +225,7 @@ class ChangelogFragmentLinter:
         """
         Lint lines of a changelog fragment.
         """
-        if isinstance(lines, list):
+        if isinstance(lines, list) and not (section.startswith('add ') and '.' in section):
             for line in lines:
                 if not isinstance(line, str):
                     errors.append((fragment.path, 0, 0,
